@@ -1,7 +1,3 @@
-"""
-THIS IS A WIP file and is subject to change, will probably be turned into a directory later on
-when more features have been implemented
-"""
 import datetime
 import pandas as pd
 from pandas import DataFrame
@@ -9,22 +5,23 @@ from typing import Union, List
 import numpy as np
 
 
-# TODO: comment
-# TODO: pretty up the code through typing conventions
-# TODO: UnitTests
-
-
-def segmentation(signals: List[int or float], freq: float = 200.0, onset: int = 0,
-                 duration: int = 30, time_unit: str = "sec") -> (List[List[int or float]], pd.DataFrame):
+def segmentation(signals: List[int or float], frequency: float = 250.0, onset: int = 0,
+                 duration: int = 30, only_signals: bool = False, time_unit: str = "sec")\
+        -> List[int or float] or (List[List[int or float]], pd.DataFrame):
     """
-    TODO: Allow the user to decide if he only wants to get the signals or also the Dataframe
-    :param onset: start of recording in seconds (int)
-    :param signals: list of EEG signals (float)
-    :param freq: sample frequency of the EEG signals (int)
-    :param duration: end of recording in seconds (int)
-    :param time_unit: the unit of time for the duration (str)
-    :return: a list of EEG signals and pandas DataFrame including the beginning and end index of the sample
+    Function that splits time series data based on the given frequency and duration
+    Args:
+        signals: list of EEG signals
+        frequency: sample frequency of the EEG signals
+        onset: start of recording in seconds
+        duration: end of recording in seconds
+        only_signals: says what the user want to recieve - either just an array of signals or a DataFrame included
+        time_unit: the unit of time for the duration
+
+    Returns: a list of EEG signals and pandas DataFrame including the beginning and end index of the sample
+
     """
+
     if time_unit == "min":
         duration *= 60
     elif time_unit == "hours":
@@ -34,41 +31,70 @@ def segmentation(signals: List[int or float], freq: float = 200.0, onset: int =
     index_dataframe = pd.DataFrame()
     temp_dataframe = pd.DataFrame()
 
-    # find the beginning index by transferring time into index using the sampling frequency
-    beg_index = int(onset * freq)
+    if only_signals:
+        # find the beginning index by transferring time into index using the sampling frequency
+        beg_index = int(onset * frequency)
 
-    # find the end index by figuring out the
-    end_index = int((onset + duration) * freq)
+        # find the end index by figuring out the
+        end_index = int((onset + duration) * frequency)
 
-    # end index might be out of scope of the list in which case we'll return as much as we can
-    if end_index > len(signals):
-        # TODO: warning/error handling over here
-        print("Warning: Duration is beyond the scope of your list, data might not be reliable")
+        # end index might be out of scope of the list in which case we'll return as much as we can
+        if end_index > len(signals):
+            print("Warning: Duration is beyond the scope of your list, data might not be reliable")
 
-        signal_list = signals[beg_index:]
-        end_index = len(signals)
-        index_dataframe['beg_index'] = [beg_index]
-        index_dataframe['end_index'] = [end_index]
+            signal_list = signals[beg_index:]
+            end_index = len(signals)
+
+            return signal_list, index_dataframe
+
+        while end_index <= len(signals) and beg_index <= len(signals):
+            # for _ in range(beg_index, len(signals), end_index):
+            signal_list.append(signals[beg_index:end_index])
+
+            onset += duration
+            beg_index = end_index + 1
+            end_index = int((onset + duration) * frequency)
+
+        if len(signal_list) < len(signals):
+            signal_list.append(signals[beg_index:])
+
+        return signal_list
+
+    else:
+        # find the beginning index by transferring time into index using the sampling frequency
+        beg_index = int(onset * frequency)
+
+        # find the end index by figuring out the
+        end_index = int((onset + duration) * frequency)
+
+        # end index might be out of scope of the list in which case we'll return as much as we can
+        if end_index > len(signals):
+            print("Warning: Duration is beyond the scope of your list, data might not be reliable")
+
+            signal_list = signals[beg_index:]
+            end_index = len(signals)
+            index_dataframe['beg_index'] = [beg_index]
+            index_dataframe['end_index'] = [end_index]
+
+            return signal_list, index_dataframe
+
+        while end_index <= len(signals) and beg_index <= len(signals):
+            # for _ in range(beg_index, len(signals), end_index):
+            signal_list.append(signals[beg_index:end_index])
+            temp_dataframe['beg_index'] = [beg_index]
+            temp_dataframe['end_index'] = [end_index]
+            index_dataframe = pd.concat([temp_dataframe, index_dataframe], axis=0, sort=True, ignore_index=True)
+
+            onset += duration
+            beg_index = end_index + 1
+            end_index = int((onset + duration) * frequency)
+
+        if len(signal_list) < len(signals):
+            signal_list.append(signals[beg_index:])
+            # index_dataframe = pd.concat([temp_dataframe, index_dataframe], sort=False)
 
         return signal_list, index_dataframe
 
-    while end_index <= len(signals) and beg_index <= len(signals):
-        # for _ in range(beg_index, len(signals), end_index):
-        signal_list.append(signals[beg_index:end_index + 1])
-        temp_dataframe['beg_index'] = [beg_index]
-        temp_dataframe['end_index'] = [end_index]
-        index_dataframe = pd.concat([temp_dataframe, index_dataframe], axis=0, sort=True, ignore_index=True)
-
-        onset += duration
-        beg_index = end_index + 1
-        end_index = int((onset + duration) * freq)
-
-    if len(signal_list) < len(signals):
-        signal_list.append(signals[beg_index:])
-        # index_dataframe = pd.concat([temp_dataframe, index_dataframe], sort=False)
-
-    return signal_list, index_dataframe
-
 
 def epochize(data: List[int or float], channel_names: List[str], epoch_len: int,
              sampling_freq: int or float, start_timestamp: datetime) -> pd.DataFrame:
@@ -112,13 +138,6 @@ def epochize(data: List[int or float], channel_names: List[str], epoch_len: int,
     return df
 
 
-"""
-TODO: Implement the functions and add them to the adaptive segmentations function
-TODO: Document and comment the functions
-TODO: Move find_transients function to some other file
-"""
-
-
 def _signal_afc(N: Union[int, float], i: Union[int, float],
                 signals: Union[List[Union[int, float]], np.ndarray]):
     R_sum = 0
@@ -143,7 +162,7 @@ def _est_signal_value(signal, p, a, n):
     return -1 * the_sum
 
 
-def error_of_signal():
+def _error_of_signal():
     return
 
 
@@ -159,13 +178,16 @@ def _calculate_sem():
     return None
 
 
-def find_transients(hello):
+def _find_transients(hello):
     # This is part of the feature extraction process
     return None
 
 
 def adaptive_segmentation(signals: Union[List[Union[int, float]], np.ndarray]):
     """
+    TODO: Implement the functions and add them to the adaptive segmentations function
+    TODO: Document and comment the functions
+    TODO: Move find_transients function to some other file
     :param signals:
     :return:
     """
@@ -183,10 +205,3 @@ def adaptive_segmentation(signals: Union[List[Union[int, float]], np.ndarray]):
     # Step 2:
 
     return None
-
-
-if __name__ == "__main__":
-    x = [i for i in range(1000000)]
-    print(len(x))
-    x, df = segmentation(x)
-    print(len(x))
\ No newline at end of file
