@@ -5,13 +5,13 @@ from numpy import ndarray
 import arora.filter.bandpass
 
 # MAKE FILTER_ORDER NOT MANDATORY HERE
-def eeg_freq_bands(eeg_signal: List[int or float], sampling_freq: float or int,
+def eeg_freq_bands(eeg_signal: List[int or float], sampling_frequency: float or int,
                    filter_order: float or int) -> (ndarray, ndarray, ndarray, ndarray):
 	"""
 
 	Args:
 		eeg_signal: One type of signals from the edf file
-		sampling_freq: The sampling frequency of the eeg signals
+		sampling_frequency: The sampling frequency of the eeg signals
 		filter_order:
 
 	Returns: Four arrays that contain each bandpass of the most common frequencies
@@ -25,8 +25,8 @@ def eeg_freq_bands(eeg_signal: List[int or float], sampling_freq: float or int,
 	delta_upper = 4
 	theta_lower = 4
 	theta_upper = 8
-	delta_band = arora.bandpass(eeg_signal, delta_lower, delta_upper, sampling_freq, filter_order)
-	theta_band = arora.bandpass(eeg_signal, theta_lower, theta_upper, sampling_freq, filter_order)
-	alpha_band = arora.bandpass(eeg_signal, alpha_lower, alpha_upper, sampling_freq, filter_order)
-	beta_band = arora.bandpass(eeg_signal, beta_lower, beta_upper, sampling_freq, filter_order)
+	delta_band = arora.bandpass(eeg_signal, delta_lower, delta_upper, sampling_frequency, filter_order)
+	theta_band = arora.bandpass(eeg_signal, theta_lower, theta_upper, sampling_frequency, filter_order)
+	alpha_band = arora.bandpass(eeg_signal, alpha_lower, alpha_upper, sampling_frequency, filter_order)
+	beta_band = arora.bandpass(eeg_signal, beta_lower, beta_upper, sampling_frequency, filter_order)
 	return delta_band, theta_band, alpha_band, beta_band
