@@ -1,4 +1,4 @@
-from .filtering import *
+from .pass_filter import *
 from .bandpass import *
 from .EEG_freqbands import *
 from .upper_lower_signal_envelopes import *
