@@ -1,5 +1,3 @@
-import random
-import time
 import warnings
 
 import matplotlib
@@ -13,12 +11,10 @@ def plot_hypnogram(
 		title=None,
 		epochlen=30,
 		ax=None,
-		verbose=True,
 		xlabel=True,
 		ylabel=True,
 		**kwargs, ):
 	"""
-	TODO: add a parameter that gets the start time of the recording to the end
 	Plot a hypnogram, based on the stages and given labeldict.
 	A labeldict should give a mapping which integer belongs to which class
 	E.g labeldict = {0: 'Wake', 4:'REM', 1:'S1', 2:'S2', 3:'SWS'}
@@ -30,7 +26,6 @@ def plot_hypnogram(
 	:param title: Title of the window
 	:param epochlen: How many seconds is one epoch in this annotation
 	:param ax: the axis in which we plot
-	:param verbose: Print stuff or not.
 	:param xlabel: Display xlabel ('Time after record start')
 	:param ylabel: Display ylabel ('Sleep Stage')
 	:param kwargs: additional arguments passed to plt.plot(), e.g. c='red'
@@ -52,16 +47,12 @@ def plot_hypnogram(
 			else:
 				labeldict = {0: 'W', 4: 'REM', 2: 'S2', 3: 'SWS'}
 		else:
-			if verbose:
-				print('could not detect labels?')
 			if 1 in stages:
 				labeldict = {0: 'W', 4: 'REM', 1: 'S1', 2: 'S2', 3: 'SWS', 5: 'A'}
 			else:
 				labeldict = {0: 'W', 4: 'REM', 2: 'S2', 3: 'SWS', 5: 'A'}
 		if -1 in stages:
 			labeldict['ARTEFACT'] = -1
-		if verbose:
-			print('Assuming {}'.format(labeldict))
 
 	# check if all stages that are in the hypnogram have a corresponding label in the dict
 	for stage in np.unique(stages):
@@ -100,29 +91,32 @@ def plot_hypnogram(
 		if i != 0:
 			y.append(p)
 			x.append(i - 1)
-		y.append(p)
-		x.append(i)
+		else:
+			y.append(p)
+			x.append(i)
 
 	assert len(rem_start) == len(rem_end), 'Something went wrong in REM length calculation'
 
-	x = np.array(x) * epochlen
+	x = np.array(x)
 	y = np.array(y)
 	y[y == 99] = y.min() - 1  # make sure Unknown stage is plotted below all else
 
 	if ax is None:
 		plt.figure()
 		ax = matplotlib.pyplot.gca()
-	formatter = matplotlib.ticker.FuncFormatter(lambda s, x: time.strftime('%H:%M', time.gmtime(s))) # will need to have the time from the start of the epoch and the end - have this as a parameter
+	#formatter = matplotlib.ticker.FuncFormatter(lambda s, x: time.strftime('%H:%M', time.gmtime(s))) # will need to have the time from the start of the epoch and the end - have this as a parameter
 
 	ax.plot(x, y, **kwargs)
 	ax.set_xlim(0, x[-1])
-	ax.xaxis.set_major_formatter(formatter)
+	#ax.xaxis.set_major_formatter(formatter)
 
 	ax.set_yticks(np.arange(len(np.unique(labels))) * -1)
 	ax.set_yticklabels(labels)
-	ax.set_xticks(np.arange(0, x[-1], 3600))
+	#ax.set_xticks(np.arange(0, x[-1], 3600))
+	#ax.set_xticks(len(stages))
+
 	if xlabel:
-		plt.xlabel('Time after recording start')
+		plt.xlabel('Epoch after recording start')
 	if ylabel:
 		plt.ylabel('Sleep Stage')
 	if title is not None:
@@ -141,8 +135,3 @@ def plot_hypnogram(
 
 	plt.show()
 
-
-if __name__ == "__main__":
-	x = np.random.randint(0, 5, 1000)
-
-	plot_hypnogram(x)
