@@ -1,36 +1,6 @@
-from random import random
 from typing import List
 import numpy as np
-from scipy import signal
-
-
-def segment_fs(signals: List[float or int], fs: int) -> List[List[int or float]]:
-	"""
-
-	Args:
-		signals:
-		fs:
-
-	Returns:
-
-	"""
-	# Maybe have this in a separate file for everyone to use
-	return [signals[x:x + fs] for x in range(0, len(signals), fs)]
-
-
-def resample(signals: List[int or float], new_fs: int, old_fs: int):
-	"""
-	Matias gave us the base of this code
-	Args:
-		signals:
-		new_fs:
-		old_fs:
-
-	Returns:
-
-	"""
-	return signal.resample(signals, int((new_fs/old_fs)*len(signals)))
-
+from arora import segment_fs
 
 def lower_frequency(signals: List[float or int], new_fs: int, method: str = "mean") -> List[float or int]:
 	"""
