@@ -14,7 +14,7 @@ class TestBandpass(unittest.TestCase):
         lower = 99
         upper = 1
         fs = 200
-        out = bandpass(inp, lower, upper, fs, 5)
+        out = bandpass(inp, fs, lower, upper, 5)
         self.assertEqual(len(out), r)
         self.assertEqual(type(out), np.ndarray)
 
