@@ -3,7 +3,7 @@ from random import random
 
 import numpy as np
 
-from arora import low_pass_filter, high_pass_filter
+from arora.filter.pass_filter import low_pass_filter, high_pass_filter
 
 
 class TestFiltering(unittest.TestCase):
@@ -13,7 +13,7 @@ class TestFiltering(unittest.TestCase):
         fs = 200
         cutoff = 99
         inp = [random() for _ in range(r)]
-        out = low_pass_filter(inp, cutoff, fs)
+        out = low_pass_filter(inp, fs, cutoff)
         self.assertEqual(len(out), r)
         self.assertNotEqual(inp, list(out))
         self.assertEqual(type(out), np.ndarray)
@@ -23,7 +23,7 @@ class TestFiltering(unittest.TestCase):
         fs = 200
         cutoff = 50
         inp = [random() for _ in range(r)]
-        out = high_pass_filter(inp, cutoff, fs)
+        out = high_pass_filter(inp, fs, cutoff)
         self.assertEqual(len(out), r)
         self.assertNotEqual(inp, list(out))
         self.assertEqual(type(out), np.ndarray)
