@@ -47,17 +47,6 @@ class MyTestCase(unittest.TestCase):
         self.assertEqual(median(inp[fs * 3:fs * 4]), out[3])
         self.assertEqual(median(inp[fs * 6:fs * 7]), out[6])
 
-    def test_not_complete_list(self):
-        r = 1000
-        fs = 70
-        inp = [round(random() * 100, 1) for _ in range(r)]
-        out = lower_frequency(inp, new_fs=fs)
-        self.assertEqual(type(out), list)
-        self.assertEqual(len(out), ceil(r / fs))
-        cutoff = (r // fs) * fs
-        self.assertEqual(min(inp[cutoff:]), out[-1])
-        self.assertEqual(min(inp[fs * 6:fs * 7]), out[6])
-
 
 if __name__ == '__main__':
     unittest.main()
